Exception: Cuniculus::Error
- Inherits:
-
StandardError
- Object
- StandardError
- Cuniculus::Error
- Defined in:
- lib/cuniculus/exceptions.rb
Overview
Cuniculus-specific exceptions
Cuniculus::Error: Default exception raised by Cuniculus. All exceptions classes defined by Cuniculus descend from this class.Cuniculus::BadlyFormattedPayload: A Cuniculus consumer received an improperly formatted job message.Cuniculus::ConfigError: Incorrect configuration passed to Cuniculus.Cuniculus::RMQConnectionError: Unable to connect to RabbitMQ.Cuniculus::RMQQueueConfigurationConflict: The queue configuration given to Cuniculus conflicts with the current configuration of the same existing queue in RabbitMQ.Cuniculus::WorkerOptionsError: Invalid options passed to cuniculus_options.
Instance Attribute Summary collapse
-
#wrapped_exception ⇒ Object
If the Cuniculus exception wraps an underlying exception, the latter is held here.
Instance Method Summary collapse
-
#cause ⇒ Exception#cause
Underlying exception
cause. - #message ⇒ Object
Instance Attribute Details
#wrapped_exception ⇒ Object
If the Cuniculus exception wraps an underlying exception, the latter is held here.
20 21 22 |
# File 'lib/cuniculus/exceptions.rb', line 20 def wrapped_exception @wrapped_exception end |
Instance Method Details
#cause ⇒ Exception#cause
Underlying exception cause
25 26 27 |
# File 'lib/cuniculus/exceptions.rb', line 25 def cause wrapped_exception || super end |
#message ⇒ Object
29 30 31 |
# File 'lib/cuniculus/exceptions.rb', line 29 def wrapped_exception&. || to_s end |